# cookiecutter-rt-pkg Changelog

Main purpose of this file is to provide a changelog for the template itself.
It is not intended to be used as a changelog for the generated project.

This changelog will document any know **BREAKING** changes between versions of the template.
Please review this new entries carefully after applying `cruft update` before committing the changes.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/).

Currently, `cookiecutter-rt-pkg` has no explicit versioning amd we purely rely on `cruft` diff.

## [Unreleased]

* **BREAKING** Introduced cookiecutter-rt-pkg template
